==> haskell-hslua-module-doclayout-1.1.0-53-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-doclayout
version:              1.1.0
visibility:           public
id:                   hslua-module-doclayout-1.1.0-L02eFsXVpb288QT0VcF0d1
key:                  hslua-module-doclayout-1.1.0-L02eFsXVpb288QT0VcF0d1
license:              MIT
copyright:            © 2020-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  8780a4ef5d344ba5c4c28b5b1af5df96
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-doclayout-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-doclayout-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.0-L02eFsXVpb288QT0VcF0d1
depends:
    base-4.16.4.0 doclayout-0.4.0.1-46hZ9EdFXbJ1TXJggbU79
    hslua-2.3.0-8UM6ZN7bpk7IWnMddBA4Kb text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-doclayout-1.1.0-68.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-doclayout
version:              1.1.0
visibility:           public
id:                   hslua-module-doclayout-1.1.0-2JgzsB8V0OSgQJSXW7vrM
key:                  hslua-module-doclayout-1.1.0-2JgzsB8V0OSgQJSXW7vrM
license:              MIT
copyright:            © 2020-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  6beca4c6254fd6f32163f820946a91f1
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-doclayout-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-doclayout-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.0-2JgzsB8V0OSgQJSXW7vrM
depends:
    base-4.16.4.0 doclayout-0.4.0.1-IxeDl9AwMnpIQPfei6hK0V
    hslua-2.3.0-EQeElTppdO0EglsvALVWWe text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
